(this.webpackJsonpstreamlit_component_template=this.webpackJsonpstreamlit_component_template||[]).push([[0],{67:function(e,t,a){e.exports=a(77)},77:function(e,t,a){"use strict";a.r(t);var r=a(5),n=a.n(r),o=a(55),l=a.n(o),s=a(0),i=a(1),c=a(2),p=a(3),d=a(32),m=a(50),g=a(16),u=a(100),b=a(103),h=a(104),v=a(99),E=a(105),f=a(62),_=a.n(f),j=a(61),x=a.n(j),y=a(102),O=["expand"],w=Object(g.a)((function(e){e.expand;var t=Object(d.a)(e,O);return n.a.createElement(v.a,t)}))((function(e){var t=e.theme;return{transform:e.expand?"rotate(180deg)":"rotate(0deg)",marginLeft:"auto",transition:t.transitions.create("transform",{duration:t.transitions.duration.shortest})}})),A=function(e){Object(c.a)(a,e);var t=Object(p.a)(a);function a(){var e;Object(i.a)(this,a);for(var r=arguments.length,o=new Array(r),l=0;l<r;l++)o[l]=arguments[l];return(e=t.call.apply(t,[this].concat(o))).state={active:!1},e.toggleActive=function(){console.log(e.state);var t=e.state.active;e.setState({active:!t}),console.log(e.state)},e.render=function(){var t=e.props.args.title,a=e.props.args.context,r=e.props.args.highlight_start,o=e.props.args.highlight_end,l=e.props.args.score,s=e.props.args.url;e.props.args.default_state&&e.toggleActive();e.props.args.key;var i=e.state.active,c=a.slice(0,r),p=a.slice(r,o),d=a.slice(o);return n.a.createElement("div",{style:{paddingTop:"0.5rem",paddingBottom:"0.5rem",whiteSpace:"pre-wrap"}},n.a.createElement(u.a,{variant:"outlined"},n.a.createElement(b.a,{title:t,subheader:l}),n.a.createElement(h.a,null,n.a.createElement(y.a,{variant:"body2"},i?c:"",n.a.createElement("span",{style:{fontWeight:i?"bold":"normal"}},p),i?d:"")),n.a.createElement(E.a,{disableSpacing:!0},n.a.createElement(v.a,{disabled:e.props.disabled,"aria-label":"open source url",href:s,target:"_PARENT"},n.a.createElement(x.a,null)),n.a.createElement(w,{expand:i,onClick:e.toggleActive,disabled:e.props.disabled,"aria-expanded":i,"aria-label":"show more"},n.a.createElement(_.a,null)))))},e}return Object(s.a)(a)}(m.a),k=Object(m.b)(A);l.a.render(n.a.createElement(n.a.StrictMode,null,n.a.createElement(k,null)),document.getElementById("root"))}},[[67,1,2]]]);
//# sourceMappingURL=main.a0c8435a.chunk.js.map